@@ -94,14 +94,9 @@ class BaseSnatch:
                     shift_seconds = 3
                 next_check = arrow.utcnow().shift(seconds=shift_seconds)
                 data = self._last_prospect(timeout=timeout)
-                if data and data.integration_status in [
-                    "SUCCESS",
-                    "ERROR",
-                    "CONN_ERROR",
-                    "NOT_FOUND",
-                ]:
+                if data and data.integration_status.is_final:
                     logger.debug(
-                        f"Data Received - Status is: {data.integration_status}"
+                        f"Data Received - Status is: {data.integration_status.value}"
                     )
                     return data
             now = arrow.utcnow()
@@ -151,7 +146,7 @@ class BaseSnatch:
         data_obj.current_environment = self.settings["current_environment"]
         data_obj.datasource_base_url = self.base_url
         data_obj.tax_id = self.tax_id
-        logger.info(f"Data received. Status is: {data_obj.integration_status}")
+        logger.info(f"Data received. Status is: {data_obj.integration_status.value}")
         return data_obj
 
     def _format_timeout_response(self, url):
@@ -268,16 +263,10 @@ class BaseSnatch:
         )
 
         # Check Status
-        if data.integration_status in [
-            "SUCCESS",
-            "INCOMPLETE",
-            "TIMEOUT",
-            "CONN_ERROR",
-            "NO_DATA",
-        ]:
+        if data.integration_status.is_final:
             return data
 
-        if data.integration_status == "WAITING":
+        if data.integration_status.need_wait:
             logger.info(f"Waiting for new data... Timeout is: {timeout} seconds.")
             wait_data = self._waiter(timeout=timeout)
             return wait_data
