@@ -21,8 +21,8 @@ class SecretManager:
     @property
     def can_read_secrets(self) -> bool:
         return (
-            asbool(os.getenv("PROJECT_READ_SSM_DATA"))
-            if os.getenv("PROJECT_READ_SSM_DATA")
+            asbool(os.getenv("SNATCH_READ_SECRETS_DATA"))
+            if os.getenv("SNATCH_READ_SECRETS_DATA")
             else True
         )
 
@@ -31,7 +31,7 @@ class SecretManager:
         if self._client:
             return self._client
 
-        region_name = os.getenv("AWS_REGION", "us-east-1")
+        region_name = os.getenv("SNATCH_AWS_REGION", "us-east-1")
         if not os.getenv("AWS_ACCESS_KEY_ID_SHARED", None):
             # just initialize, will check for `.aws/credentials` file
             self._client = boto3.client("secretsmanager", region_name=region_name)
