@@ -1,6 +1,12 @@
+import sys
 from dataclasses import dataclass
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Type, TypedDict
+from typing import Any, Dict, List, Optional, Type
+
+if sys.version_info >= (3, 8):
+    from typing import TypedDict
+else:
+    from typing_extensions import TypedDict
 
 from loguru import logger
 from marshmallow import EXCLUDE, Schema, fields, post_load, pre_load
